========
air-sans
========

A trame application for analysis, inspection, and reduction of multi-detector data produced by the Small-Angle Neutron Scattering (SANS) instruments.


* Free software: Apache Software License


Installing
----------

Install the application

.. code-block:: console

    pip install -e .


Run the application

.. code-block:: console

    air-sans --data ./data
